==> libnetconf-0.9.1.tar.gz: libnetconf/doc/doxygen/html/d8/d55/group__transapi.js <==
var group__transapi =
[
    [ "clbk", "d0/dd1/structclbk.html", [
      [ "func", "d0/dd1/structclbk.html#a32d40f1c10b08061196dc6b7a9ab072c", null ],
      [ "path", "d0/dd1/structclbk.html#a44196e6a5696d10442c29e639437196e", null ]
    ] ],
    [ "transapi", "d9/dc0/structtransapi.html", [
      [ "clbks_order", "d9/dc0/structtransapi.html#a9da1a4a7373fb09e2f82fb7f1a81f9b2", null ],
      [ "close", "d9/dc0/structtransapi.html#a414e48f893be7474f64d2c61a9c012b9", null ],
      [ "config_modified", "d9/dc0/structtransapi.html#aa234e35582e991cd6e5c43047e315528", null ],
      [ "data_clbks", "d9/dc0/structtransapi.html#a44e5e883d6586faf97047d23c7bcebf7", null ],
      [ "erropt", "d9/dc0/structtransapi.html#acb50180a0bc032bef4b6af94d8596528", null ],
      [ "file_clbks", "d9/dc0/structtransapi.html#a829682c0ae04089a665f2de8f1378446", null ],
      [ "get_state", "d9/dc0/structtransapi.html#a6c403c3ae7c1ca5654fdaf60b60ba16b", null ],
      [ "init", "d9/dc0/structtransapi.html#a8cb29ceda55d20ecbec3784d536851db", null ],
      [ "ns_mapping", "d9/dc0/structtransapi.html#a517eb18d6321490a3439ae595edbf9a4", null ],
      [ "rpc_clbks", "d9/dc0/structtransapi.html#ae40968626e78bf37871565d98292b1b7", null ]
    ] ],
    [ "transapi_data_callbacks", "d6/dcb/structtransapi__data__callbacks.html", [
      [ "callbacks", "d6/dcb/structtransapi__data__callbacks.html#a37c3f849c79cfe4991c6d0a6526b12d7", null ],
      [ "callbacks_count", "d6/dcb/structtransapi__data__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "data", "d6/dcb/structtransapi__data__callbacks.html#a735984d41155bc1032e09bece8f8d66d", null ]
    ] ],
    [ "transapi_file_callbacks", "de/df8/structtransapi__file__callbacks.html", [
      [ "callbacks", "de/df8/structtransapi__file__callbacks.html#af315aee2dd9c7f04ef44d3dc4f1565d9", null ],
      [ "callbacks_count", "de/df8/structtransapi__file__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "func", "de/df8/structtransapi__file__callbacks.html#a9c1038ab827316debf4109f49818519f", null ],
      [ "path", "de/df8/structtransapi__file__callbacks.html#a3b02c6de5c049804444a246f7fdf46b4", null ]
    ] ],
    [ "transapi_rpc_callbacks", "d0/df8/structtransapi__rpc__callbacks.html", [
      [ "arg_count", "d0/df8/structtransapi__rpc__callbacks.html#ad4e017d16d393756e4e27927d06084ec", null ],
      [ "arg_order", "d0/df8/structtransapi__rpc__callbacks.html#ae5d4a40ee77a8f12e0cb49f592719338", null ],
      [ "callbacks", "d0/df8/structtransapi__rpc__callbacks.html#a0ad28c1d0d3518ca0b3d631a20eaf48d", null ],
      [ "callbacks_count", "d0/df8/structtransapi__rpc__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "func", "d0/df8/structtransapi__rpc__callbacks.html#a15569b8737513da9b760834a5e5be80c", null ],
      [ "name", "d0/df8/structtransapi__rpc__callbacks.html#a5ac083a645d964373f022d03df4849c8", null ]
    ] ],
    [ "XMLDIFF_OP", "d8/d55/group__transapi.html#ga10d59d84527f735d2781dbbb629a4488", [
      [ "XMLDIFF_ERR", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488af2c3cac34cb7553ac93e8f3ad8acee3c", null ],
      [ "XMLDIFF_NONE", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a45a3557c464a0d85a333b68634df5561", null ],
      [ "XMLDIFF_ADD", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488adc0f4fc8354a1e293db5efd4f8e6f0b1", null ],
      [ "XMLDIFF_REM", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a149cdeec9d87bdbb700861f773759129", null ],
      [ "XMLDIFF_MOD", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a27c20d1fff6c4a35673bea8c6bbe23c4", null ],
      [ "XMLDIFF_CHAIN", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a4038204cbce3cfa24153b304b95e99a6", null ],
      [ "XMLDIFF_SIBLING", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488afed6f3e2b762ffe2cad87676c48c488f", null ],
      [ "XMLDIFF_REORDER", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a732f013a15b9125ea90d20f16d2f2d8e", null ]
    ] ],
    [ "ncds_add_augment_transapi", "d8/d55/group__transapi.html#gacd42f4efcc256fa4ecdaa021f82d6d1f", null ],
    [ "ncds_add_augment_transapi_static", "d8/d55/group__transapi.html#ga7f6f5af711045d8598f283ec09b9167a", null ],
    [ "ncds_new_transapi", "d8/d55/group__transapi.html#ga80e69b4cada8c35e5e358287e8af3d85", null ],
    [ "ncds_new_transapi_static", "d8/d55/group__transapi.html#gaaf4e4daa7fa8be965ded41eb006a6713", null ]
];

==> libnetconf-0.10.0.tar.gz: libnetconf/doc/doxygen/html/d8/d55/group__transapi.js <==
var group__transapi =
[
    [ "clbk", "d0/dd1/structclbk.html", [
      [ "func", "d0/dd1/structclbk.html#aecdb0401379b34c8aa71dd594b79d45d", null ],
      [ "path", "d0/dd1/structclbk.html#a44196e6a5696d10442c29e639437196e", null ]
    ] ],
    [ "transapi", "d9/dc0/structtransapi.html", [
      [ "clbks_order", "d9/dc0/structtransapi.html#a9da1a4a7373fb09e2f82fb7f1a81f9b2", null ],
      [ "close", "d9/dc0/structtransapi.html#a414e48f893be7474f64d2c61a9c012b9", null ],
      [ "config_modified", "d9/dc0/structtransapi.html#aa234e35582e991cd6e5c43047e315528", null ],
      [ "data_clbks", "d9/dc0/structtransapi.html#a44e5e883d6586faf97047d23c7bcebf7", null ],
      [ "erropt", "d9/dc0/structtransapi.html#acb50180a0bc032bef4b6af94d8596528", null ],
      [ "file_clbks", "d9/dc0/structtransapi.html#a829682c0ae04089a665f2de8f1378446", null ],
      [ "get_state", "d9/dc0/structtransapi.html#a6c403c3ae7c1ca5654fdaf60b60ba16b", null ],
      [ "init", "d9/dc0/structtransapi.html#a8cb29ceda55d20ecbec3784d536851db", null ],
      [ "ns_mapping", "d9/dc0/structtransapi.html#a517eb18d6321490a3439ae595edbf9a4", null ],
      [ "rpc_clbks", "d9/dc0/structtransapi.html#ae40968626e78bf37871565d98292b1b7", null ],
      [ "version", "d9/dc0/structtransapi.html#aad880fc4455c253781e8968f2239d56f", null ]
    ] ],
    [ "transapi_data_callbacks", "d6/dcb/structtransapi__data__callbacks.html", [
      [ "callbacks", "d6/dcb/structtransapi__data__callbacks.html#a37c3f849c79cfe4991c6d0a6526b12d7", null ],
      [ "callbacks_count", "d6/dcb/structtransapi__data__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "data", "d6/dcb/structtransapi__data__callbacks.html#a735984d41155bc1032e09bece8f8d66d", null ]
    ] ],
    [ "transapi_file_callbacks", "de/df8/structtransapi__file__callbacks.html", [
      [ "callbacks", "de/df8/structtransapi__file__callbacks.html#af315aee2dd9c7f04ef44d3dc4f1565d9", null ],
      [ "callbacks_count", "de/df8/structtransapi__file__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "func", "de/df8/structtransapi__file__callbacks.html#a9c1038ab827316debf4109f49818519f", null ],
      [ "path", "de/df8/structtransapi__file__callbacks.html#a3b02c6de5c049804444a246f7fdf46b4", null ]
    ] ],
    [ "transapi_rpc_callbacks", "d0/df8/structtransapi__rpc__callbacks.html", [
      [ "callbacks", "d0/df8/structtransapi__rpc__callbacks.html#a0ad28c1d0d3518ca0b3d631a20eaf48d", null ],
      [ "callbacks_count", "d0/df8/structtransapi__rpc__callbacks.html#a853d73f0f495147dba4842e9f860d1f0", null ],
      [ "func", "d0/df8/structtransapi__rpc__callbacks.html#a4e198e0f385cc9d713aa918597858fbb", null ],
      [ "name", "d0/df8/structtransapi__rpc__callbacks.html#a5ac083a645d964373f022d03df4849c8", null ]
    ] ],
    [ "XMLDIFF_OP", "d8/d55/group__transapi.html#ga10d59d84527f735d2781dbbb629a4488", [
      [ "XMLDIFF_ERR", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488af2c3cac34cb7553ac93e8f3ad8acee3c", null ],
      [ "XMLDIFF_NONE", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a45a3557c464a0d85a333b68634df5561", null ],
      [ "XMLDIFF_ADD", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488adc0f4fc8354a1e293db5efd4f8e6f0b1", null ],
      [ "XMLDIFF_REM", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a149cdeec9d87bdbb700861f773759129", null ],
      [ "XMLDIFF_MOD", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a27c20d1fff6c4a35673bea8c6bbe23c4", null ],
      [ "XMLDIFF_CHAIN", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a4038204cbce3cfa24153b304b95e99a6", null ],
      [ "XMLDIFF_SIBLING", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488afed6f3e2b762ffe2cad87676c48c488f", null ],
      [ "XMLDIFF_REORDER", "d8/d55/group__transapi.html#gga10d59d84527f735d2781dbbb629a4488a732f013a15b9125ea90d20f16d2f2d8e", null ]
    ] ],
    [ "ncds_add_augment_transapi", "d8/d55/group__transapi.html#gacd42f4efcc256fa4ecdaa021f82d6d1f", null ],
    [ "ncds_add_augment_transapi_static", "d8/d55/group__transapi.html#ga7f6f5af711045d8598f283ec09b9167a", null ],
    [ "ncds_new_transapi", "d8/d55/group__transapi.html#ga80e69b4cada8c35e5e358287e8af3d85", null ],
    [ "ncds_new_transapi_static", "d8/d55/group__transapi.html#gaaf4e4daa7fa8be965ded41eb006a6713", null ]
];
